.. _Nipype: https://nipype.readthedocs.io/en/latest/
.. _BIDS: https://bids.neuroimaging.io/
.. _`BIDS Derivatives`: https://bids-specification.readthedocs.io/en/stable/05-derivatives/01-introduction.html
.. _`BEP 011`: https://bids-specification.readthedocs.io/en/bep011/05-derivatives/04-structural-derivatives.html
.. _`BEP 012`: https://bids-specification.readthedocs.io/en/bep012/05-derivatives/05-functional-derivatives.html
.. _Installation: installation.html
.. _workflows: workflows.html
.. _FSL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
.. _ANTs: https://stnava.github.io/ANTs/
.. _FreeSurfer: https://surfer.nmr.mgh.harvard.edu/
.. _`submillimeter reconstruction`: https://surfer.nmr.mgh.harvard.edu/fswiki/SubmillimeterRecon
.. _`mri_robust_template`: https://surfer.nmr.mgh.harvard.edu/fswiki/mri_robust_template
.. _AFNI: https://afni.nimh.nih.gov/
.. _GIFTI: https://www.nitrc.org/projects/gifti/
.. _`Connectome Workbench`: https://www.humanconnectome.org/software/connectome-workbench.html
.. _`HCP Pipelines`: https://humanconnectome.org/software/hcp-mr-pipelines/
.. _`Docker wrapper`: https://pypi.python.org/pypi/fmriprep-docker
.. _`Docker Engine`: https://www.docker.com/products/container-runtime
.. _`Docker installation`: https://docs.docker.com/install/
.. _`Docker Hub`: https://hub.docker.com/r/nipreps/fmriprep/tags
.. _Singularity: https://github.com/singularityware/singularity
..  _SPM: https://www.fil.ion.ucl.ac.uk/spm/software/spm12/
.. _TACC: https://www.tacc.utexas.edu/
.. _tedana: https://github.com/me-ica/tedana
.. _`T2* workflow`: https://tedana.readthedocs.io/en/latest/generated/tedana.workflows.t2smap_workflow.html#tedana.workflows.t2smap_workflow  # noqa
.. _`citation boilerplate`: https://www.nipreps.org/intro/transparency/#citation-boilerplates
